@@ -15,7 +15,7 @@ SCALE = 0.5
 OFFSCREEN_SPACE = 00
 SCREEN_WIDTH = 1000
 SCREEN_HEIGHT = 800
-SCREEN_TITLE = "XFC 2022: ASTEROID SMASHER"
+SCREEN_TITLE = "XFC ASTEROID SMASHER"
 LEFT_LIMIT = 0
 RIGHT_LIMIT = SCREEN_WIDTH
 BOTTOM_LIMIT = 0
@@ -24,5 +24,6 @@ TOP_LIMIT = SCREEN_HEIGHT
 # Settings related to drawing within the window (font sizes and colors)
 FONT_SIZE1 = 15
 FONT_SIZE2 = 13
+FONT_SIZE3 = 11
 WHITE_COLOR = (255, 255, 255, 255)
 BLUE_COLOR = (150, 150, 255, 150)
