@@ -38,8 +38,10 @@ class Score:
         # self.deaths = 0
 
         self.asteroids_hit = [0, 0]
+        self.asteroids_hit_by_bullets = [0, 0]
         self.bullets_fired = [0, 0]
-        self.bullets_remaining = [0, 0]
+        # self.bullets_remaining = [0, 0]
+        self.bullets_remaining = [-1, -1]
         # self.distance_travelled = [0, 0]
         self.deaths = [0, 0]
 
@@ -79,7 +81,8 @@ class Score:
     @property
     def accuracy(self) -> list[float]:
         # return 0.0 if not self.bullets_fired else self.asteroids_hit / self.bullets_fired
-        return [0.0 if not bullets_fired else ast_hit / bullets_fired for bullets_fired, ast_hit in zip(self.bullets_fired, self.asteroids_hit)]
+        # return [0.0 if not bullets_fired else ast_hit / bullets_fired for bullets_fired, ast_hit in zip(self.bullets_fired, self.asteroids_hit)]
+        return [0.0 if not bullets_fired else ast_hit / bullets_fired for bullets_fired, ast_hit in zip(self.bullets_fired, self.asteroids_hit_by_bullets)]
 
     @property
     def fraction_total_asteroids_hit(self) -> list[float]:
@@ -252,7 +255,12 @@ class Scenario:
     @property
     def bullet_limit(self) -> int:
         if self._ammo_limit_multiplier:
-            return round(self.max_asteroids*self._ammo_limit_multiplier)
+            temp = round(self.max_asteroids*self._ammo_limit_multiplier)
+            if temp == 0:
+                return temp + 1
+            else:
+                return temp
+
         else:
             return -1
 
